@@ -2,7 +2,7 @@ import inspect
 
 def custom_property(f):
     def wrapper(self, *args, **kwargs):
-        if self._is_builtin_callled and f.__name__ in self._static_properties:
+        if self._is_builtin_called and f.__name__ in self._static_properties:
             return self._static_properties[f.__name__]
         if not self._has_generated:
             self.parseData()
